@@ -2,7 +2,7 @@
 # define CPPAD_CORE_UNDEF_HPP
 // SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 // SPDX-FileCopyrightText: Bradley M. Bell <bradbell@seanet.com>
-// SPDX-FileContributor: 2003-22 Bradley M. Bell
+// SPDX-FileContributor: 2003-23 Bradley M. Bell
 // ----------------------------------------------------------------------------
 
 /*
@@ -17,10 +17,10 @@ that are used by the CppAD examples and tests.
 # undef CPPAD_HASH_TABLE_SIZE                used by test_more/optimize.cpp
 # undef EIGEN_MATRIXBASE_PLUGIN              example use of Eigen with CppAD
 # undef CPPAD_HAS_COLPACK                    used by speed/cppad/sparse_*.cpp
-# undef CPPAD_C_COMPILER_GNU                 used to select dll examples.
-# undef CPPAD_C_COMPILER_MSVC                used to select dll examples.
-# undef CPPAD_C_COMPILER_CLANG               used to select dll examples.
-
+# undef CPPAD_C_COMPILER_GNU_FLAGS           used by dll examples.
+# undef CPPAD_C_COMPILER_MSVC_FLAGS          used by dll examples.
+# undef CPPAD_C_COMPILER_CMD                 used by dll examples.
+# undef CPPAD_SYSTEM_IS_DARWIN        used by example/utility/cppad_vector.hpp
 
 // for conditional testing when implicit conversion is not present
 # undef CPPAD_DEPRECATED
@@ -38,6 +38,7 @@ that are used by the CppAD examples and tests.
 # undef CPPAD_COND_EXP_BASE_REL
 # undef CPPAD_COND_EXP_REL
 # undef CPPAD_CPPADVECTOR
+# undef CPPAD_DEBUG_AND_RELEASE
 # undef CPPAD_EIGENVECTOR
 # undef CPPAD_FOLD_AD_VALUED_BINARY_OPERATOR
 # undef CPPAD_FOLD_ASSIGNMENT_OPERATOR
@@ -49,13 +50,16 @@ that are used by the CppAD examples and tests.
 # undef CPPAD_HAS_MKSTEMP
 # undef CPPAD_HAS_TMPNAM_S
 # undef CPPAD_INLINE_FRIEND_TEMPLATE_FUNCTION
+# undef CPPAD_IS_SAME_UNSIGNED_INT_SIZE_T
 # undef CPPAD_LIB_EXPORT
 # undef CPPAD_MAX_NUM_CAPACITY
 # undef CPPAD_MIN_DOUBLE_CAPACITY
 # undef CPPAD_NDEBUG_NOEXCEPT
 # undef CPPAD_NOEXCEPT
+# undef CPPAD_PADDING_BLOCK_T
 # undef CPPAD_STANDARD_MATH_UNARY_AD
 # undef CPPAD_STDVECTOR
+# undef CPPAD_IS_SAME_TAPE_ADDR_TYPE_SIZE_T
 # undef CPPAD_TRACE_CAPACITY
 # undef CPPAD_TRACE_THREAD
 # undef CPPAD_TRACK_DEBUG
